@@ -15,3 +15,11 @@ test_that("list_hosts", {
 test_that("list_hosts", {
   expect_error(svc$list_hosts(MaxResults = 20), NA)
 })
+
+test_that("list_repository_links", {
+  expect_error(svc$list_repository_links(), NA)
+})
+
+test_that("list_repository_links", {
+  expect_error(svc$list_repository_links(MaxResults = 20), NA)
+})
